This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-bcel.git

commit 31ab85a74e17f6fdf8977bb448ed3475c98d7446
Author: Gary David Gregory (Code signing key) <ggreg...@apache.org>
AuthorDate: Sat Oct 22 16:11:33 2022 -0400

    Use camel case for parameter names and local variable names
---
 src/main/java/org/apache/bcel/generic/Select.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/main/java/org/apache/bcel/generic/Select.java 
b/src/main/java/org/apache/bcel/generic/Select.java
index 05d3c185..58c6671d 100644
--- a/src/main/java/org/apache/bcel/generic/Select.java
+++ b/src/main/java/org/apache/bcel/generic/Select.java
@@ -233,11 +233,11 @@ public abstract class Select extends BranchInstruction 
implements VariableLength
     }
 
     /**
      * @param fixed_length the fixed_length to set
      * @since 6.0
      */
-    final void setFixed_length(final int fixed_length) {
-        this.fixed_length = fixed_length;
+    final void setFixed_length(final int fixedLength) {
+        this.fixed_length = fixedLength;
     }
 
     /** @since 6.0 */
@@ -233,11 +233,11 @@ public abstract class Select extends BranchInstruction 
 
     /**
-     * @param fixed_length the fixed_length to set
+     * @param fixedLength the fixed_length to set
      * @since 6.0
      */

Reply via email to